@@ -1,6 +1,10 @@
+import sys
+from pathlib import Path
+from typing import Set
+
 import parsy
 
-from .check import check_files
+from .check import check_file, check_files
 from .file import File
 from .issue import Issue, IssueLocation
 from .parse import make_parser
@@ -20,6 +24,10 @@ def parse_file(path_and_config):
     with path.open("r") as f:
         source = f.read()
 
+    return parse_source(path, config, source)
+
+
+def parse_source(path: Path, config, source: str):
     parser = make_parser(config)
 
     try:
@@ -32,11 +40,11 @@ def parse_file(path_and_config):
         return [], file
     except parsy.ParseError as error:
         location = get_parsy_error_location(error, path)
-        issue = Issue(location, "Parse error: " + str(error), "parse-error")
+        issue = Issue(location, "Parse error: " + str(error), "parse_error")
         return [issue], None
 
 
-def lint(paths, config):
+def lint(paths: Set[Path], config):
     issues = []
     files = []
 
@@ -52,7 +60,34 @@ def lint(paths, config):
         if file is not None:
             files.append(file)
 
-    if not config.get("parse_only", False):
-        issues += check_files(files, config)
+    if config.get("parse_only", False):
+        return issues
+
+    rules = config.get("rules")
+
+    if rules:
+        issues += check_files(files, rules)
+
+    return issues
+
+
+def lint_one(path: Path, config):
+    if not path.is_file() and str(path) == "-":
+        source = sys.stdin.read()
+        parse_issues, file = parse_source(
+            config.get("stdin_filepath", path), config, source
+        )
+    else:
+        parse_issues, file = parse_file((path, config))
+
+    issues = parse_issues
+
+    if config.get("parse_only", False):
+        return issues
+
+    rules = config.get("rules")
+
+    if rules and file is not None:
+        issues += check_file(file, rules)
 
     return issues
