@@ -150,6 +150,7 @@ DEFAULT_JINJA_STRUCTURED_ELEMENTS_NAMES = [
 # XXX: It could be better and simpler to only allow ASCII whitespaces here.
 whitespace = P.regex(r"\s*")
 mandatory_whitespace = P.regex(r"\s+")
+spaces_between_attr = mandatory_whitespace.desc("space(s) between attributes")
 
 
 def until(parser):
@@ -415,7 +416,7 @@ def make_attributes_parser(config, jinja):
 
     attrs = interpolated(
         (
-            whitespace.then(jinja_attr) | mandatory_whitespace.then(attribute)
+            whitespace.then(jinja_attr) | spaces_between_attr.then(attribute)
         ).many()
     )
 
@@ -591,6 +592,8 @@ def make_jinja_parser(config, content):
         (names[0], names)
         for names in (
             DEFAULT_JINJA_STRUCTURED_ELEMENTS_NAMES
+            + config.get("template_tags", [])
+            # Deprecated, will be removed in a future release.
             + config.get("jinja_custom_elements_names", [])
         )
     ).values()
